/*
 * $Id: stack.h,v 1.5 2004/06/28 09:51:09 jklein Exp $
 * $Author: jklein $
 * $Log: stack.h,v $
 * Revision 1.5  2004/06/28 09:51:09  jklein
 * interface was changed in scale/iterator.h
 *
 * Revision 1.4  2004/06/26 06:58:13  jklein
 * small fix in each header files.
 *
 * Revision 1.3  2004/06/24 15:16:50  jklein
 * sxarray_t was added for abstruction of collection structure.
 *
 * Revision 1.2  2004/06/21 16:44:17  jklein
 * Added iterator.
 */

/**
   <p>
   $B%9%?%C%/9=B$$H0lO"$NA`:n$rDs6!$9$k!#A`:n$NBgH>$O%^%/%m$GDj5A$5$l$F$$$k!#(B
   </p>
*/


#ifndef _SCALE_STACK_H_
#define _SCALE_STACK_H_

#include "scale/commons.h"
#include "scale/vector.h"

typedef svector_t sstack_t;


#define s_stack_alloc()			(sstack_t *)s_vector_alloc()
#define s_stack_allocn(n)		(sstack_t *)s_vector_allocn(n)
#define s_stack_free(s)			s_vector_free((svector_t *)(s))
#define s_stack_size(s)			s_vector_size((svector_t *)(s))
#define s_stack_push(s, c)		s_vector_add((svector_t *)(s), c)
#define s_stack_find(s, c, f)	s_vector_find((svector_t *)(s), c, f);

spointer		s_stack_peek(sstack_t *);
spointer		s_stack_pop(sstack_t *);


#endif /* _SCALE_STACK_H_ */
